==> typesense-0.4.0-py2.py3-none-any.whl: examples/curation_operations.py <==
import typesense

# Curation is a Typesense Premium feature (see: https://typesense.org/premium)

client = typesense.Client({
  'master_node': {
    'host': 'localhost',
    'port': '8108',
    'protocol': 'http',
    'api_key': 'abcd'
  },
  'read_replica_nodes': [{
    'host': 'localhost',
    'port': '9108',
    'protocol': 'http',
    'api_key': 'abcd'
  }],
  'timeout_seconds': 2
})

# Create a collection

create_response = client.collections.create({
  "name": "books",
  "fields": [
    {"name": "title", "type": "string" },
    {"name": "authors", "type": "string[]" },
    {"name": "authors_facet", "type": "string[]", "facet": True },
    {"name": "publication_year", "type": "int32" },
    {"name": "publication_year_facet", "type": "string", "facet": True },
    {"name": "ratings_count", "type": "int32" },
    {"name": "average_rating", "type": "float" },
    {"name": "image_url", "type": "string" }
  ],
  "default_sorting_field": "ratings_count"
})

print(create_response)

# Create or update an override

create_override_response = client.collections["books"].overrides.upsert('hermione-exact', {
  "rule": {
    "query": "hermione",
    "match": "exact"
  },
  "includes": [
    {"id": "1", "position": 1},
  ]
})

print(create_override_response)

# List all overrides

print(client.collections["books"].overrides.retrieve())

# Retrieve the configuration of a specific override

print(client.collections["books"].overrides["hermione-exact"].retrieve())

# Add a book

hunger_games_book = {
  'id': '1', 'original_publication_year': 2008, 'authors': ['JK Rowling'], 'average_rating': 4.34,
  'publication_year': 2008, 'publication_year_facet': '2008', 'authors_facet': ['JK Rowling'],
  'title': 'Harry Potter and the Goblet of Fire',
  'image_url': 'https://images.gr-assets.com/books/1447303603m/2767052.jpg',
  'ratings_count': 4780653
}

client.collections['books'].documents.create(hunger_games_book)

# Search for a book

print(client.collections['books'].documents.search({
    'q': 'hermione',
    'query_by': 'title',
    'sort_by': 'ratings_count:desc'
}))

# Delete an override

print(client.collections['books'].overrides["hermione-exact"].delete())

==> typesense-0.5.0-py2.py3-none-any.whl: examples/curation_operations.py <==
import typesense

# Curation is a Typesense Premium feature (see: https://typesense.org/premium)

client = typesense.Client({
  'api_key': 'abcd',
  'nodes': [{
    'host': 'localhost',
    'port': '8108',
    'protocol': 'http'
  }],
  'connection_timeout_seconds': 2
})

# Create a collection

create_response = client.collections.create({
  "name": "books",
  "fields": [
    {"name": "title", "type": "string" },
    {"name": "authors", "type": "string[]" },
    {"name": "authors_facet", "type": "string[]", "facet": True },
    {"name": "publication_year", "type": "int32" },
    {"name": "publication_year_facet", "type": "string", "facet": True },
    {"name": "ratings_count", "type": "int32" },
    {"name": "average_rating", "type": "float" },
    {"name": "image_url", "type": "string" }
  ],
  "default_sorting_field": "ratings_count"
})

print(create_response)

# Create or update an override

create_override_response = client.collections["books"].overrides.upsert('hermione-exact', {
  "rule": {
    "query": "hermione",
    "match": "exact"
  },
  "includes": [
    {"id": "1", "position": 1},
  ]
})

print(create_override_response)

# List all overrides

print(client.collections["books"].overrides.retrieve())

# Retrieve the configuration of a specific override

print(client.collections["books"].overrides["hermione-exact"].retrieve())

# Add a book

hunger_games_book = {
  'id': '1', 'original_publication_year': 2008, 'authors': ['JK Rowling'], 'average_rating': 4.34,
  'publication_year': 2008, 'publication_year_facet': '2008', 'authors_facet': ['JK Rowling'],
  'title': 'Harry Potter and the Goblet of Fire',
  'image_url': 'https://images.gr-assets.com/books/1447303603m/2767052.jpg',
  'ratings_count': 4780653
}

client.collections['books'].documents.create(hunger_games_book)

# Search for a book

print(client.collections['books'].documents.search({
    'q': 'hermione',
    'query_by': 'title',
    'sort_by': 'ratings_count:desc'
}))

# Delete an override

print(client.collections['books'].overrides["hermione-exact"].delete())
